## Ab-initio reconstruction in single particle fluorescence imaging

Reconstructs a particle from its rotated views observed by fluorescence imaging.

### TO-DO

- [ ] Marginalisation
Au lieu de considérer seulement l'orientation avec la plus faible énergie, considérer toutes les orientations pondérées par leur niveau d'énergie.

- [ ] Apprendre un poids sur les particules
Pas encore très bien défini. Dans l'optique d'éliminer des particules parasites.

- [ ] Multirésolution
Augmenter progressivement le nombre de coefficients de Fourier à utiliser dans la reconstruction. Permet d'améliorer la vitesse de calcul.

- [ ] Estimation de la PSF en s'inspirant de [EpiDEMIC](https://icy.bioimageanalysis.org/plugin/epidemic/).

- [ ] Reconstruction multi-canaux.

- [ ] Paramétrisation de la reconstruction pour cas particuliers. Exemple : pore nucléaire 8 doublets en cylindre

- [ ] Ajout de la FSC
